Green
=====

Green is a colorful, clean, fast and powerful test runner for Python unit
tests.  Compare it to `nose`_ or `trial`_.


Documentation
-------------

Please visit the `GitHub page for Green`_ for full documentation, including a
nice tutorial on how to correctly layout unit tests in your own python project.


Features
--------

- **Colorful** - Terminal output makes good use of color when the terminal supports it.
- **Clean** - Vertically-aligned statuses.  Low redundancy in output.
- **Fast** - Can run tests in independent subprocesses.
- **Powerful** - Multi-target + auto-discovery.
- **Traditional** - Use the normal ``unittest`` classes and methods for your unit tests.
- **Descriptive** - Four verbosity levels, from just dots to full docstring output.
- **Thorough** - Built-in, optional integration with `coverage`_
- **Modern** - Supports Python 2.7, 3.3, 3.4, and `PyPy`_
- **Portable** - Completely supports OS X, Linux, and BSDs (and maybe Windows).
- **Flexible** - Optional HTML output.


.. _nose: https://nose.readthedocs.org
.. _trial: http://twistedmatrix.com/trac/wiki/TwistedTrial
.. _GitHub page for Green: https://github.com/CleanCut/green#green
.. _coverage: http://nedbatchelder.com/code/coverage/
.. _PyPy: http://pypy.org
